@@ -49,6 +49,10 @@ class Subscription(models.Model):
     class Meta:
         unique_together = [('user', 'plan')]
 
+
+    @classmethod
+    def create_from_payment_method(cls, token, plan, user):
+
     @classmethod
     def create_from_token(cls, token, plan, user):
         try:
@@ -57,8 +61,6 @@ class Subscription(models.Model):
             obj = cls(user=user, plan=plan)
 
         with transaction.atomic():
-            token = stripe.Token.retrieve(token)
-
             if not obj.customer_id:
                 customer = stripe.Customer.create(
                         email=user.email,
@@ -66,13 +68,19 @@ class Subscription(models.Model):
 
                 obj.customer_id = customer.id
 
-            source = stripe.Source.create(
-                type=token.type,
-                token=token.id)
+            if token.starts_with('tok_'):
+                token = stripe.Token.retrieve(token)
 
-            stripe.Customer.create_source(
-                obj.customer_id,
-                source=source.id)
+                source = stripe.Source.create(
+                    type=token.type,
+                    token=token.id)
+
+                stripe.Customer.create_source(
+                    obj.customer_id,
+                    source=source.id)
+            elif token.starts_with('pm_'):
+                pm = stripe.PaymentMethod.retrieve(token)
+                stripe.PaymentMethod.attach(pm.id, customer=obj.customer_id)
 
             sub = stripe.Subscription.create(
                 customer=obj.customer_id,
